"""Validation workflow for LAN Switch Interconnect subscription objects."""

from typing import Any

from orchestrator.targets import Target
from orchestrator.workflow import StepList, begin, done, step, workflow
from orchestrator.workflows.steps import resync, store_process_subscription, unsync
from orchestrator.workflows.utils import wrap_modify_initial_input_form

from gso.services.lso_client import LSOState, anonymous_lso_interaction


@step("Check config for drift")
def validate_config(subscription: dict[str, Any]) -> LSOState:
    """Workflow step for running a playbook that checks whether config has drifted."""
    return {
        "playbook_name": "lan_switch_interconnect.yaml",
        "inventory": {"all": {"hosts": {None: None}}},
        "extra_vars": {
            "subscription_json": subscription,
            "verb": "deploy",
            "dry_run": "true",
            "is_verification_workflow": "true",
        },
    }


@workflow(
    "Validate LAN Switch Interconnect", target=Target.SYSTEM, initial_input_form=(wrap_modify_initial_input_form(None))
)
def validate_lan_switch_interconnect() -> StepList:
    """Validate an existing LAN Switch Interconnect."""
    return (
        begin
        >> store_process_subscription(Target.SYSTEM)
        >> unsync
        >> anonymous_lso_interaction(validate_config)
        >> resync
        >> done
    )
